{% load mote_tags %}

<button class="Button {{ data.modifiers }}">
    <i>{{ data.Italic.text }}</i>
</button>
{% if data.OtherElement.element %}
    {% render_element data.OtherElement.element %}
{% endif %}
