.ButtonGroup {
    $block: &;
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    align-items: stretch;
    justify-content: flex-start;

    &-item {
        & + & {
            margin-left: ms(-5);
        }
    }
}

.Button {
    display: block;
    padding: ms(-2) ms(2);
    transition: .15s ease-in-out;
    border: 1px solid $color-primary-2;
    border-radius: .3rem;
    background-color: $color-primary-2;
    color: $color-white;
    font-family: $font-headings;
    font-size: ms(-2);
    font-weight: 300;
    letter-spacing: .15em;
    line-height: 1;
    text-align: center;
    text-decoration: none;
    text-transform: uppercase;
    overflow: hidden;

    &:hover,
    &:focus,
    &:active,
    &.is-active {
        background-color: lighten($color-primary-2, 5%);
    }
}
