.Navigation {
    $block: &;

    &-group {
        display: block;

        &--tier1 {

        }

        &--tier2 {

        }
    }

    &-item {
        display: block;

        &--tier1 {
            margin-bottom: ms(5);
        }

        &--tier2 {
            padding-left: ms(1);
            border-left: 5px solid $color-primary-1;
        }
    }

    &-itemLink {
        display: block;
        transition: .15s ease-in-out;
        color: $color-primary-1;
        text-decoration: none;

        &:active,
        &:hover,
        &.is-active {
            color: $color-primary-2;
        }

        &--tier1 {
            margin-bottom: ms(-3);
            font-family: $font-headings;
            font-weight: 700;
            text-transform: uppercase;
        }

        &--tier2 {
            padding: ms(-5);
        }
    }
}
