<!DOCTYPE html>

{% load staticfiles %}

<html lang="">

<head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>Mote</title>
    <meta name="description" content="">
    <meta name="viewport" content="width=device-width, initial-scale=1">

    <!-- TODO: Get rid of or move this stuff into the webpack bundle. -->
    <link href="https://fonts.googleapis.com/css?family=PT+Sans:400,700|Prompt:100,200,300,400,700" rel="stylesheet">
    <link rel="stylesheet" type="text/css" href="{% static "mui/generated_statics/bundles/mui-website.styles.css" %}"/>

    <link rel="stylesheet" type="text/css" href="{% static "mote/js/libs/prism/css/prism.css" %}"/>
    <script src="{% static "mote/js/libs/prism/js/prism.js" %}"></script>

    <script src="{% static "mote/js/libs/jquery/js/jquery.js" %}"></script>
    <script src="{% static "mote/js/libs/sticky-kit/js/jquery.sticky-kit.js" %}"></script>
    <script src="{% static "mote/js/libs/hideseek/js/jquery.hideseek.js" %}"></script>
    <script src="{% static "mote/js/libs/lazysizes/js/lazysizes.js" %}"></script>
    <script src="{% static "mote/js/mote.js" %}"></script>

    <script defer src="{% static "mui/generated_statics/bundles/mui-website.main.js" %}"></script>
</head>

<body data-library="{{ library }}">

    {% block header %}
    <header role="banner" class="SiteHead">
        <div class="SiteHead-brand">
            <a href="{% url "mote:home" %}" class="Logo">
                <span class="Logo-text">
                    M<span>o</span>te
                </span>
            </a>
        </div>
    </header>
    {% endblock %}

    <section role="section" class="Hero">
        {% block hero %}
        {% endblock %}
    </section>

    <main role="main" class="ContentArea">
        {% block menu %}{% endblock %}

        <section role="section" class="ContentArea-body">
            {% block content %}
            {% endblock %}
        </section>
    </main>

    <footer class="SiteFoot">

    </footer>
</body>
</html>
