.NavGrid {
    $block: &;
    $item-padding: ms(2);
    display: flex;
    flex-direction: row;
    flex-wrap: wrap;
    align-items: stretch;
    justify-content: space-between;

    &-item {
        display: flex;
        flex-grow: 1;
        align-items: stretch;
        margin: $item-padding;
    }

    &-tile {
        display: block;
        width: 100%;
        padding: ms(2) ms(3);
        transition: .15s ease-in-out;
        border: 1px solid $color-grey;
        background-color: $color-white;
        color: $color-primary-1;
        font-family: $font-headings;
        font-size: ms(4);
        font-weight: 700;
        text-align: center;
        text-decoration: none;

        &:hover,
        &:active {
            background-color: $color-primary-1;
            color: $color-white;
        }
    }
}
