.progress {

  display: inline-block;

  transition: all 0.3s;

  margin-top: -10%;

  padding: 10px 0px 0px 50px;

  opacity: 0;

  .bar {
    height: 20px;
    width: 100%;
    background-color: $color-grey-lightest;
  }

  h3 {
     margin: 0px 0px 30px 0px;
  }

  hr {
    margin: 1rem 0;
  }

  p {
    margin: 5px 0px 5px 0px !important;
    font-size: 0.8rem;
  }

}
